pub fn parse_psi_line(line: &str) -> Option<PsiMetrics>Expand description
Parse a single PSI line into PsiMetrics.
Accepts lines starting with "some" or "full".
Returns None if the line does not match the expected PSI format.
pub fn parse_psi_line(line: &str) -> Option<PsiMetrics>Parse a single PSI line into PsiMetrics.
Accepts lines starting with "some" or "full".
Returns None if the line does not match the expected PSI format.